@@ -6,6 +6,8 @@ from .lp import RoAffine, RoConstr
 from .lp import DecVar, RandVar, DecLinConstr, DecCvxConstr
 from .lp import DecRoConstr
 from .lp import Scen
+from .lp import Solution
+from .lpg_solver import solve as def_sol
 from .subroutines import *
 import numpy as np
 import pandas as pd
@@ -390,10 +392,17 @@ class Model:
                 const = constr.const
                 roaffine = linear @ drule - const.reshape(const.size)
                 if isinstance(roaffine, RoAffine):
-                    ew_constr = RoConstr(roaffine, constr.sense)
+                    if (roaffine.raffine.linear.nnz == 0 and
+                        not roaffine.raffine.const.any()):
+                        ew_constr = LinConstr(roaffine.dec_model,
+                                              roaffine.affine.linear,
+                                              - roaffine.affine.const,
+                                              constr.sense)
+                    else:
+                        ew_constr = RoConstr(roaffine, constr.sense)
                 elif isinstance(roaffine, Affine):
                     ew_constr = LinConstr(roaffine.model, roaffine.linear,
-                                          roaffine.const, constr.sense)
+                                          -roaffine.const, constr.sense)
                 else:
                     raise TypeError('Unknown type.')
             elif isinstance(constr, DecCvxConstr):
@@ -471,7 +480,10 @@ class Model:
         ro_constr = []
         for i in range(linear.shape[0]):
             alpha = self.ro_model.dvar(num_scen)
-            beta = self.ro_model.dvar((num_rand, num_event))
+            if num_event:
+                beta = self.ro_model.dvar((num_rand, num_event))
+            else:
+                beta = 0
 
             left = alpha @ p
             for j in range(num_event):
@@ -485,6 +497,7 @@ class Model:
                 if raffine:
                     if isinstance(drule, RoAffine):
                         temp = drule.affine
+                        left = left.affine.reshape(left.shape)
                     elif isinstance(drule, Affine):
                         temp = drule
                     else:
@@ -493,7 +506,7 @@ class Model:
                     new_raffine = raffine.linear[row_ind] @ temp
                     new_raffine = new_raffine.reshape((1, new_raffine.size))
                     left = RoAffine(new_raffine + raffine.const[i, :num_rand],
-                                    left, constr.rand_model)
+                                    left, constr.rand_model) ######################
 
                 event_indices = [k for k in range(num_event)
                                  if s in ambset.exp_constr_indices[k]]
@@ -511,14 +524,15 @@ class Model:
 
         return ro_constr
 
-    def solve(self, solver, display=True, export=False):
+    def solve(self, solver=None, display=True, export=False):
         """
         Solve the model with the selected solver interface.
 
         Parameters
         ----------
-            solver : {grb_solver, msk_solver}
-                Solver interface used for model solution.
+            solver : {None, lpg_solver, grb_solver, msk_solver}
+                Solver interface used for model solution. Use default solver
+                if solver=None.
             display : bool
                 Display option of the solver interface.
             export : bool
@@ -526,8 +540,17 @@ class Model:
                 is generated if the option is True.
         """
 
-        solution = solver.solve(self.do_math(), display, export)
-        self.ro_model.solution = solution
+        if solver is None:
+            solution = def_sol(self.do_math(), display, export)
+        else:
+            solution = solver.solve(self.do_math(), display, export)
+
+        if isinstance(solution, Solution):
+            self.ro_model.solution = solution
+        else:
+            x = solution.x
+            self.ro_model.solution = Solution(x[0], x, solution.status)
+
         self.ro_model.rc_model.solution = solution
         self.solution = solution
 
